@@ -1,4 +1,5 @@
 import sys
+import time
 import click
 import jmespath
 from cloudscale import Cloudscale, CloudscaleApiException
@@ -28,6 +29,7 @@ class CloudscaleCommand:
             sys.exit(1)
 
         self._output = output
+        self._retries = 30
 
         self.cloud_resource_name = cloud_resource_name
         self.verbose = verbose
@@ -49,7 +51,7 @@ class CloudscaleCommand:
                 response = [response]
             return to_table(response, self.headers, self.response_transform_json)
 
-    def cmd_list(self, filter_tag=None, filter_json=None, action=None, delete=False, force=False):
+    def cmd_list(self, filter_tag=None, filter_json=None, action=None, delete=False, force=False, wait=False):
         if action and delete:
             click.echo("Error: --action and --delete are mutually exclusive", err=True)
             sys.exit(1)
@@ -73,6 +75,7 @@ class CloudscaleCommand:
                             sys.exit(1)
                         uuid = r['href'].split('/')[-1]
                         self.cmd_delete(uuid=uuid, force=True, skip_query=True)
+
                 elif action:
                     if not force:
                         click.confirm(f"Do you want to {action}?", abort=True)
@@ -83,6 +86,13 @@ class CloudscaleCommand:
                         uuid = r['href'].split('/')[-1]
                         with Spinner(text=f"{action.capitalize()} {uuid}"):
                             getattr(self.get_client_resource(), action)(uuid)
+
+                    if wait:
+                        response = self.get_client_resource().get_all(filter_tag)
+                        for r in response:
+                            uuid = r['href'].split('/')[-1]
+                            self.wait_for_status(uuid=uuid)
+
                     with Spinner(text="Querying"):
                         response = self.get_client_resource().get_all(filter_tag)
                     click.echo(self._format_output(response))
@@ -131,7 +141,9 @@ class CloudscaleCommand:
                 except ValueError as e:
                     click.echo(e, err=True)
                     sys.exit(1)
-            with Spinner(text="Creating"):
+
+            name = kwargs.get(self.resource_name_key, '')
+            with Spinner(text=f"Creating {name}"):
                 response = self.get_client_resource().create(**kwargs)
             if not silent:
                 click.echo(self._format_output(response))
@@ -141,8 +153,7 @@ class CloudscaleCommand:
             click.echo(e, err=True)
             sys.exit(1)
 
-    def cmd_update(self, uuid, tags, clear_tags, clear_all_tags, **kwargs):
-        with Spinner(text=f"Processing"):
+    def cmd_update(self, uuid, tags, clear_tags, clear_all_tags, wait=False, **kwargs):
             try:
                 with Spinner(text=f"Querying by UUID {uuid}"):
                     self.get_client_resource().get_by_uuid(uuid)
@@ -158,29 +169,30 @@ class CloudscaleCommand:
                     sys.exit(1)
 
                 if len(results) > 1:
-                    click.echo(f"Error: More than one resource found for {self.cloud_resource_name} having name: {uuid}. Use UUID to update.", err=True)
+                    click.echo(f"Error: More than one resource found for {self.cloud_resource_name} having name: {uuid}. Please use UUID to select the resource.", err=True)
                     sys.exit(1)
 
                 # Single resource found, remember UUID
                 uuid = results[0]['href'].split('/')[-1]
 
             try:
-                if any([clear_all_tags, tags, clear_tags]):
-                    _tags = dict()
-                    if not clear_all_tags:
-                        response = self.get_client_resource().get_by_uuid(uuid=uuid)
-                        _tags = response.get('tags', dict()).copy()
-                        for k in clear_tags:
-                            _tags.pop(k, None)
+                with Spinner(text=f"Processing tags"):
+                    if any([clear_all_tags, tags, clear_tags]):
+                        _tags = dict()
+                        if not clear_all_tags:
+                            response = self.get_client_resource().get_by_uuid(uuid=uuid)
+                            _tags = response.get('tags', dict()).copy()
+                            for k in clear_tags:
+                                _tags.pop(k, None)
 
-                    if tags:
-                        try:
-                            _tags.update(tags_to_dict(tags))
-                        except ValueError as e:
-                            click.echo(e, err=True)
-                            sys.exit(1)
-                else:
-                    _tags = None
+                        if tags:
+                            try:
+                                _tags.update(tags_to_dict(tags))
+                            except ValueError as e:
+                                click.echo(e, err=True)
+                                sys.exit(1)
+                    else:
+                        _tags = None
 
 
                 with Spinner(text=f"Updating by UUID {uuid}"):
@@ -189,7 +201,13 @@ class CloudscaleCommand:
                         tags=_tags,
                         **kwargs,
                     )
-                    response = self.get_client_resource().get_by_uuid(uuid=uuid)
+
+                if wait:
+                    response = self.wait_for_status(uuid=uuid)
+                else:
+                    with Spinner(text=f"Querying {uuid}"):
+                        response = self.get_client_resource().get_by_uuid(uuid)
+
                 click.echo(self._format_output(response))
             except Exception as e:
                 click.echo(e, err=True)
@@ -230,7 +248,7 @@ class CloudscaleCommand:
             click.echo(e, err=True)
             sys.exit(1)
 
-    def cmd_act(self, action, uuid):
+    def cmd_act(self, action, uuid, wait=False):
         with Spinner(text=f"Processing"):
             try:
                 with Spinner(text=f"Querying by UUID {uuid}"):
@@ -247,7 +265,7 @@ class CloudscaleCommand:
                     sys.exit(1)
 
                 if len(results) > 1:
-                    click.echo(f"Error: More than one resource found for {self.cloud_resource_name} having name: {uuid}. Use UUID to update.", err=True)
+                    click.echo(f"Error: More than one resource found for {self.cloud_resource_name} having name: {uuid}. Please use UUID to select the resource.", err=True)
                     sys.exit(1)
 
                 # Single resource found, remember UUID
@@ -257,9 +275,25 @@ class CloudscaleCommand:
                 with Spinner(text=f"{action} {uuid}"):
                     getattr(self.get_client_resource(), action)(uuid)
 
-                with Spinner(text=f"Querying {uuid}"):
-                    response = self.get_client_resource().get_by_uuid(uuid)
+                if wait:
+                    response = self.wait_for_status(uuid=uuid)
+                else:
+                    with Spinner(text=f"Querying {uuid}"):
+                        response = self.get_client_resource().get_by_uuid(uuid)
                 click.echo(self._format_output(response))
             except Exception as e:
                 click.echo(e, err=True)
                 sys.exit(1)
+
+    def wait_for_status(self, uuid):
+        with Spinner(text=f"Waiting for status {uuid}: ...") as sp:
+            for retry in range(1, self._retries):
+                response = self.get_client_resource().get_by_uuid(uuid)
+                if response['status'] != 'changing':
+                    break
+                sp.text = f"Waiting for status {uuid}: {response['status']}"
+                time.sleep(1)
+            else:
+                sp.text = f"Waiting for status {uuid} timed out."
+                time.sleep(1)
+        return response
